@@ -3,7 +3,7 @@
 #include <config.h>
 #endif
 
-#include <iostream.h>
+#include <iostream>
 #include <math.h>
 #include <stdlib.h>
 #include <string.h>
@@ -26,15 +26,11 @@
 #include "IntlDefs.h"
 #include "rotate_and_fire.h"
 
+namespace std { }
+using namespace std;
+
 RotateAndFire::RotateAndFire(const char* name, const char* colour)
 {
-#ifdef ENABLE_NLS
-# ifdef HAVE_LOCALE_H
-  setlocale( LC_MESSAGES, "" );
-# endif
-  bindtextdomain( "RealTimeBattle", RTB_LOCALEDIR );
-  textdomain( "RealTimeBattle" );
-#endif
 
   robot_name = new char[strlen(name) + 1];
   strcpy(robot_name, name);
@@ -49,9 +45,9 @@ RotateAndFire::RotateAndFire(const char* name, const char* colour)
   brake_value = 0.0;
 
   // Get random seed from the clock
-  timeval current_time;
-  gettimeofday(&current_time, NULL);
-  srand(current_time.tv_usec);
+  // timeval current_time;
+  // gettimeofday(&current_time, NULL);
+  // srand(current_time.tv_usec);
 
   // We want to know when RotateTo and RotateAmount finishes
   robot_option( SEND_ROTATION_REACHED, 1 );
