@@ -44,7 +44,6 @@ ArenaWindow::ArenaWindow( const int default_width,
                           const int default_y_pos )
 {
   // The window widget
-
   window_p = gtk_window_new( GTK_WINDOW_TOPLEVEL );
   gtk_widget_set_name( window_p, "RTB Arena" );
 
@@ -53,15 +52,11 @@ ArenaWindow::ArenaWindow( const int default_width,
   gtk_container_border_width( GTK_CONTAINER( window_p ), 12 );
 
   if( default_width != -1 && default_height != -1 )
-#if GTK_MAJOR_VERSION == 1 && GTK_MINOR_VERSION >= 1
     {
       gtk_window_set_default_size( GTK_WINDOW( window_p ),
                                    default_width, default_height );
       gtk_widget_set_usize( window_p , 185, 120 );
     }
-#else
-  gtk_widget_set_usize( window_p, default_width, default_height );
-#endif
   if( default_x_pos != -1 && default_y_pos != -1 )
     gtk_widget_set_uposition( window_p, default_x_pos, default_y_pos );
 
@@ -122,12 +117,8 @@ ArenaWindow::ArenaWindow( const int default_width,
 
   gtk_widget_set_events( drawing_area, GDK_EXPOSURE_MASK );
 
-#if GTK_MAJOR_VERSION == 1 && GTK_MINOR_VERSION >= 1
   gtk_scrolled_window_add_with_viewport
     ( GTK_SCROLLED_WINDOW( scrolled_window ), drawing_area );
-#else
-  gtk_container_add( GTK_CONTAINER( scrolled_window ), drawing_area );
-#endif
   gtk_widget_show( drawing_area );
 
   window_shown = controlwindow_p->is_arenawindow_checked();
@@ -145,6 +136,7 @@ ArenaWindow::ArenaWindow( const int default_width,
 
   if( !window_shown )
     gtk_widget_hide( window_p );
+  
 }
 
 ArenaWindow::~ArenaWindow()
@@ -167,7 +159,7 @@ ArenaWindow::set_window_shown( bool win_shown )
 }
 
 // Warning: event can be NULL, do not use event!
-void
+gboolean
 ArenaWindow::hide_window( GtkWidget* widget, GdkEvent* event,
                           class ArenaWindow* arenawindow_p )
 {
@@ -178,13 +170,10 @@ ArenaWindow::hide_window( GtkWidget* widget, GdkEvent* event,
       if( controlwindow_p->is_arenawindow_checked() )
         {
           GtkWidget* menu_item = controlwindow_p->get_show_arena_menu_item();
-#if GTK_MAJOR_VERSION == 1 && GTK_MINOR_VERSION >= 1
           gtk_check_menu_item_set_active( GTK_CHECK_MENU_ITEM( menu_item ), FALSE );
-#else
-          gtk_check_menu_item_set_state( GTK_CHECK_MENU_ITEM( menu_item ), FALSE );
-#endif
         }
     }
+	return true;
 }
 
 void
@@ -570,4 +559,3 @@ ArenaWindow::redraw( GtkWidget* widget, GdkEventExpose* event,
     arenawindow_p->draw_everything();
   return FALSE;
 }
-
