@@ -21,7 +21,10 @@ Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 #include <config.h>
 #endif
 
-#include <iostream.h>
+#include <iostream>
+
+using namespace std;
+
 #include "List.h"
 #include "String.h"
 
