@@ -18,7 +18,9 @@ Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 
 #include <gtk/gtk.h>
-#include <fstream.h>
+#include <fstream>
+
+using namespace std;
 
 #include "OptionsWindow.h"
 #include "IntlDefs.h"
@@ -218,7 +220,6 @@ OptionsWindow::OptionsWindow( const int default_width,
       gtk_widget_show( entry_table );
       gtk_widget_show( button_table );
 
-#if GTK_MAJOR_VERSION == 1 && GTK_MINOR_VERSION >= 1
       if( i == PAGE_SIZE_OF_WINDOWS )
         {
           GtkWidget* grab_button = gtk_button_new_with_label
@@ -228,7 +229,6 @@ OptionsWindow::OptionsWindow( const int default_width,
           gtk_box_pack_start( GTK_BOX( page_vbox ), grab_button, FALSE, FALSE, 0 );
           gtk_widget_show( grab_button );
         }
-#endif
 
       GtkWidget* label = gtk_label_new( page_titles[i] );
       gtk_widget_show( label );
@@ -335,8 +335,10 @@ OptionsWindow::set_all_options()
       option_info_t<String>* string_opts = the_opts.get_all_string_options();
       for(int i=0;i<LAST_DOUBLE_OPTION;i++)
         {
-          double entry_value = str2dbl
+			
+		double entry_value = str2dbl
             ( gtk_entry_get_text( GTK_ENTRY( double_opts[i].entry ) ) );
+			
           if( entry_value > double_opts[i].max_value )
             entry_value = double_opts[i].max_value;
           if( entry_value < double_opts[i].min_value )
@@ -382,8 +384,10 @@ OptionsWindow::update_all_gtk_entries()
   option_info_t<String>* string_opts = the_opts.get_all_string_options();
 
   for(int i=0;i<LAST_DOUBLE_OPTION;i++)
+	  {
     gtk_entry_set_text( GTK_ENTRY( double_opts[i].entry ),
                         String(double_opts[i].value).chars() );
+  		}
   for(int i=0;i<LAST_LONG_OPTION;i++)
     {
       if( long_opts[i].datatype == ENTRY_INT )
@@ -532,7 +536,6 @@ void
 OptionsWindow::grab_windows( GtkWidget* widget,
                              class OptionsWindow* optionswindow_p )
 {
-#if GTK_MAJOR_VERSION == 1 && GTK_MINOR_VERSION >= 1
   option_info_t<long>* long_opts = the_opts.get_all_long_options();
   if( the_gui.is_arenawindow_up() )
     {
@@ -602,7 +605,6 @@ OptionsWindow::grab_windows( GtkWidget* widget,
       long_opts[OPTION_STATISTICS_WINDOW_SIZE_Y].value = height;
       optionswindow_p->update_all_gtk_entries();
     }
-#endif
 }
 
 void
