@@ -37,9 +37,9 @@ Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 #  include <time.h>
 # endif
 #endif
-#ifdef HAVE_SYS_WAIT_H
+
 # include <sys/wait.h>
-#endif
+
 
 #include <errno.h>
 #ifdef HAVE_GETOPT_H
@@ -52,15 +52,15 @@ Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 # include <locale.h>
 #endif
 
-#include <iostream.h>
+#include <iostream>
 
 #ifdef FLOATINGPOINT_H
-#include <floatingpoint.h>
+#include <floatingpoint>
 #endif
 
 #ifndef NO_GRAPHICS
 #include "ControlWindow.h"
-#endif NO_GRAPHICS
+#endif 
 
 #include "IntlDefs.h"
 #include "Options.h"
@@ -138,7 +138,7 @@ update_function(gpointer data)
 
   return res;
 }
-#else NO_GRAPHICS
+#else 
 void
 update_function(const long int interval_usec)
 {
@@ -158,9 +158,9 @@ update_function(const long int interval_usec)
   while( res );
 
 }
-#endif NO_GRAPHICS
+#endif 
 
-RETSIGTYPE
+void
 sig_handler (int signum)
 {
   int pid;
@@ -182,7 +182,7 @@ sig_handler (int signum)
   signal(signum, sig_handler);
 }
 
-RETSIGTYPE
+void
 sigfpe_handler(int signum)
 {
   signal(signum, sigfpe_handler);
@@ -370,7 +370,7 @@ parse_command_line(int argc, char **argv)
   if( the_arena_controller.auto_start_and_end == false 
 #ifndef NO_GRAPHICS      
       && no_graphics
-#endif NO_GRAPHICS     
+#endif      
       )
     {
       cerr << "No graphics and no tournament file gives me nothing to do. Leaving ..." << endl;
@@ -389,13 +389,19 @@ main ( int argc, char* argv[] )
 #endif
 
 #ifndef NO_GRAPHICS
-#ifdef HAVE_LOCALE_H
-  gtk_set_locale();
+
+	
+#ifdef ENABLE_NLS
+  bindtextdomain ("RealTimeBattle", PACKAGE_LOCALE_DIR);
+  bind_textdomain_codeset ("RealTimeBattle", "UTF-8");
+  textdomain ("RealTimeBattle");
 #endif
 
-  gtk_init (&argc, &argv);
-#endif NO_GRAPHICS
+  gtk_set_locale ();
 
+  gtk_init (&argc, &argv);
+#endif 
+/*
 #ifdef HAVE_LOCALE_H
   setlocale( LC_MESSAGES, "" );
   setlocale( LC_NUMERIC, "POSIX" );
@@ -406,7 +412,7 @@ main ( int argc, char* argv[] )
   bindtextdomain( "RealTimeBattle", "/usr/local/share/locale" );
 #endif
   textdomain( "RealTimeBattle" );
-
+*/
   parse_command_line(argc, argv);
 
   if( the_arena_controller.tournament_filename != "" )
@@ -429,18 +435,23 @@ main ( int argc, char* argv[] )
     }
 
 
-  gint timeout_tag;      
+  gint timeout_tag;     
+
   double interval = 1000.0*the_opts.get_d( OPTION_UPDATE_INTERVAL ) - 10.0; 
+  
+  //updating too fast?
+  if ( interval < 40 ) interval = 40;
+
+
   timeout_tag = gtk_timeout_add( (unsigned int) interval,
                                  GtkFunction(update_function), (gpointer) NULL );
-
+ 
   gtk_main();
-
-#else !NO_GRAPHICS
+#else 
   
   update_function( (long int)(the_opts.get_d( OPTION_UPDATE_INTERVAL ) * 1000000.0) );
   
-#endif !NO_GRAPHICS
+#endif 
 
   return EXIT_SUCCESS;
 }
