@@ -24,9 +24,12 @@ Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 #include <fcntl.h>
 #include <unistd.h>
 #include <signal.h>
-#include <iostream.h>
+#include <iostream>
+#include <fstream>
 #include <math.h>
 
+using namespace std;
+
 #ifdef TIME_WITH_SYS_TIME 
 # include <sys/time.h>
 # include <time.h>
@@ -59,6 +62,7 @@ Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 # include "ScoreWindow.h"
 #endif
 
+
 //  #include "Gui.h"
 //  #include "MovingObject.h"
 //  #include "Arena.h"
@@ -260,7 +264,7 @@ Robot::start_process()
     {
       close(pipe_out[0]);     // Close input side of pipe_out
       close(pipe_in[1]);      // Close output side of pipe_in  
-      
+		
       pipes[0] = pipe_out[1];
       pipes[1] = pipe_in[0];
 
@@ -281,13 +285,19 @@ Robot::start_process()
         Error(true, "Couldn't change pd_flags for pipe_out in robot " + robot_filename, 
               "Robot::start_process, parent");
 
-      outstreamp = new ofstream(pipe_out[1]);
-      instreamp = new ifstream(pipe_in[0]);
+	// Der Schrott geht nimmer in libstdc++ v3
+
+     // outstreamp = new ofstream(pipe_out[1]);
+     // instreamp = new ifstream(pipe_in[0]);
+      
+     outstreamp = new boost::fdostream(pipe_out[1]);  
+     instreamp = new boost::fdistream(pipe_in[0]);
+              
     }
 
   // wait some time to let process start up
-
-  struct timeval timeout;
+ 
+  struct timeval timeout; 
   timeout.tv_sec = 0;
   timeout.tv_usec = 40000;  //  1/25 s 
 
@@ -306,17 +316,17 @@ void
 Robot::update_cpu_time_used()
 {
   if( network_robot || !process_running ) return;
-
+  
   String procfilename = "/proc/" + String(pid) + "/stat";
   ifstream procfile(procfilename.chars());
   if( !procfile ) return;
-  
-  char buf[16];
+   
+  char buf[64];
   
   // step to the correct value
   for(int i=0; i<15; i++) 
     procfile >> buf; 
-  
+
   // The next four values should be added to get the correct cpu usage
   double current_cpu = 0.0;
   int jiffies;  
@@ -1003,6 +1013,7 @@ Robot::send_message(const message_to_robot_type msg_type ...)
 {
   va_list args;
   va_start(args, msg_type);
+		
   *outstreamp << message_to_robot[msg_type].msg << " ";
   for(int i=0; i<message_to_robot[msg_type].number_of_args; i++)
     {
@@ -1021,13 +1032,14 @@ Robot::send_message(const message_to_robot_type msg_type ...)
           *outstreamp << va_arg(args, char*) << " ";
           break;   
         case HEX:
-          *outstreamp << hex << va_arg(args, int) << " ";
+          *outstreamp << std::hex << va_arg(args, int) << " ";
           break;
         default:
           Error(true, "Couldn't send message, unknown arg_type", "Robot::send_message");
         }
     }
   *outstreamp << endl;
+
 }
 
 
@@ -1045,12 +1057,19 @@ Robot::get_messages()
   *instreamp >> ws;
   instreamp->clear();
   instreamp->peek();
-  while( !instreamp->eof() )
+
+	
+
+  while( !(*instreamp >> msg_name).eof() )
     {
-      *instreamp >> msg_name;
+	
+     
+      //*instreamp >> msg_name;
       msg_t = name2msg_from_robot_type(msg_name);
       //      cerr << "Got message: " << msg_name << endl;
 
+
+
       *instreamp >> ws;
 
       switch(msg_t)
@@ -1128,7 +1147,7 @@ Robot::get_messages()
             {
               long home_colour, away_colour;
               
-              *instreamp >> hex >> home_colour >> away_colour >> dec;
+              *instreamp >> std::hex >> home_colour >> away_colour >> std::dec;
               
               // TODO: check if colour is already allocated! 
               set_colour( realtime_arena.find_free_colour(home_colour, away_colour, this) );
@@ -1334,7 +1353,7 @@ Robot::get_messages()
                   the_gui.get_arenawindow_p()->
                     draw_line(start + center, direction, 1.0, gdk_colour);
                 }
-#endif NO_GRAPHICS              
+#endif              
             }
           break;
 
@@ -1357,7 +1376,7 @@ Robot::get_messages()
                   the_gui.get_arenawindow_p()->
                     draw_circle(c, r, gdk_colour, false);
                 }
-#endif NO_GRAPHICS
+#endif 
             }         
           break;          
 
@@ -1491,6 +1510,8 @@ Robot::get_messages()
       instreamp->clear();
       instreamp->peek();
     }
+    
+   
 }
 
 message_from_robot_type
@@ -1782,4 +1803,4 @@ Robot::get_stat_pixmap( GdkWindow* win, GdkPixmap*& pixm, GdkBitmap*& bitm )
   stat_pixmap.get_pixmap( gdk_colour, win, pixm, bitm ); 
 }
 
-#endif NO_GRAPHICS
+#endif
