@@ -23,6 +23,8 @@ Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
 #include <gtk/gtk.h>
 
+#define HAVE_DIRENT_H 1
+
 #if HAVE_DIRENT_H
 # if HAVE_SYS_TYPES_H
 #  include <sys/types.h>
@@ -60,6 +62,7 @@ StartTournamentWindow::StartTournamentWindow( const int default_width,
                                               const int default_x_pos,
                                               const int default_y_pos )
 {
+  
   tournament_started_flag = false;
 
   filesel = NULL;
@@ -75,12 +78,9 @@ StartTournamentWindow::StartTournamentWindow( const int default_width,
   gtk_container_border_width( GTK_CONTAINER( window_p ), 12 );
 
   if( default_width != -1 && default_height != -1 )
-#if GTK_MAJOR_VERSION == 1 && GTK_MINOR_VERSION >= 1
     gtk_window_set_default_size( GTK_WINDOW( window_p ),
                                  default_width, default_height );
-#else
-  gtk_widget_set_usize( window_p, default_width, default_height );
-#endif
+
   if( default_x_pos != -1 && default_y_pos != -1 )
     gtk_widget_set_uposition( window_p, default_x_pos, default_y_pos );
 
@@ -135,8 +135,9 @@ StartTournamentWindow::StartTournamentWindow( const int default_width,
 
           // Make a horizontal ruler between robots and arenas
           GtkWidget* hsep = gtk_hseparator_new();
-          gtk_box_pack_start( GTK_BOX( vbox ), hsep, FALSE, FALSE, 0 );
+          gtk_box_pack_start( GTK_BOX( vbox ), hsep, FALSE, TRUE, 0 );
           gtk_widget_show( hsep );
+
         }
 
       GtkWidget* hbox = gtk_hbox_new( FALSE, 10 );
@@ -162,6 +163,7 @@ StartTournamentWindow::StartTournamentWindow( const int default_width,
               vbox2 = gtk_vbox_new( FALSE, 10 );
               gtk_box_pack_start( GTK_BOX( hbox ), vbox2, FALSE, FALSE, 0 );
               gtk_widget_show( vbox2 );
+	
             }
           GtkWidget* button = gtk_button_new_with_label( button_labels[i] );
           struct select_buttons_t* s_button;
@@ -187,9 +189,12 @@ StartTournamentWindow::StartTournamentWindow( const int default_width,
 
       for( ; li.ok() ; li++ )
         {
+        	
           String* current_dir = li();
           DIR* dir;
-          if( NULL != (dir = opendir(current_dir->chars())))
+          
+          
+          if( dir = opendir(current_dir->chars()) )
             {
               struct dirent * entry;
               while (NULL != ( entry = readdir( dir ) ) )
@@ -201,12 +206,11 @@ StartTournamentWindow::StartTournamentWindow( const int default_width,
                       char* lst[] = { entry->d_name };
 
                       int row = gtk_clist_append( GTK_CLIST( dir_clist ), lst );
-#if GTK_MAJOR_VERSION != 1 || GTK_MINOR_VERSION < 1
                       gtk_clist_set_foreground( GTK_CLIST( dir_clist ), row, 
                                                 the_gui.get_fg_gdk_colour_p());
                       gtk_clist_set_background( GTK_CLIST( dir_clist ), row, 
                                                 the_gui.get_bg_gdk_colour_p());
-#endif
+
                       start_tournament_info_t* info;
                       info = new start_tournament_info_t
                         ( row, false,
@@ -401,6 +405,7 @@ StartTournamentWindow::StartTournamentWindow( const int default_width,
   load_tournament_file( the_opts.get_s( OPTION_TMP_RTB_DIR ) +
                         tmp_tournament_file, false );
   gtk_widget_show( window_p );
+  
 }
 
 StartTournamentWindow::~StartTournamentWindow()
@@ -414,7 +419,6 @@ StartTournamentWindow::add_clist( GtkWidget* clist, GtkWidget* box )
   int all_clists_width=150;
   int all_clists_height= 150;
 
-#if GTK_MAJOR_VERSION == 1 && GTK_MINOR_VERSION >= 1
   GtkObject* hadj = gtk_adjustment_new( 0.0, 0.0, 100.0, 1.0, 1.0, 1.0 );
   GtkObject* vadj = gtk_adjustment_new( 0.0, 0.0, 100.0, 1.0, 1.0, 1.0 );
   GtkWidget* scrolled_win =
@@ -425,7 +429,6 @@ StartTournamentWindow::add_clist( GtkWidget* clist, GtkWidget* box )
                                   GTK_POLICY_AUTOMATIC );
   gtk_box_pack_start( GTK_BOX( box ), scrolled_win, TRUE, TRUE, 5 );
   gtk_widget_show( scrolled_win );
-#endif
 
   gtk_clist_set_selection_mode( GTK_CLIST( clist ),
                                 GTK_SELECTION_MULTIPLE );
@@ -438,7 +441,6 @@ StartTournamentWindow::add_clist( GtkWidget* clist, GtkWidget* box )
   gtk_signal_connect( GTK_OBJECT( clist ), "unselect_row",
                       (GtkSignalFunc) StartTournamentWindow::selection_made, this );
 
-#if GTK_MAJOR_VERSION == 1 && GTK_MINOR_VERSION >= 1
   gtk_clist_set_shadow_type( GTK_CLIST( clist ),
                              GTK_SHADOW_IN );
   gtk_widget_set_usize( clist, all_clists_width,
@@ -450,22 +452,12 @@ StartTournamentWindow::add_clist( GtkWidget* clist, GtkWidget* box )
   if( clist_style == NULL )
     clist_style = gtk_style_new();
   else
-    clist_style = gtk_style_copy(clist_style);
+  clist_style = gtk_style_copy(clist_style);
   clist_style->base[GTK_STATE_NORMAL] = *(the_gui.get_bg_gdk_colour_p());
   clist_style->base[GTK_STATE_ACTIVE] = make_gdk_colour( 0xffffff );
   clist_style->bg[GTK_STATE_SELECTED] = make_gdk_colour( 0xf0d2b4 );
   clist_style->fg[GTK_STATE_SELECTED] = *(the_gui.get_fg_gdk_colour_p());
   gtk_widget_set_style( clist, clist_style );
-#else
-  gtk_clist_set_border( GTK_CLIST( clist ),
-                        GTK_SHADOW_IN );
-  gtk_clist_set_policy( GTK_CLIST( clist ),
-                        GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC );
-  gtk_widget_set_usize( clist,
-                        all_clists_width + 20, all_clists_height + 20 );
-  gtk_box_pack_start( GTK_BOX( box ), clist,
-                      TRUE, TRUE, 0 );
-#endif
   gtk_widget_show( clist );
 }
 
@@ -629,23 +621,17 @@ new_tournament( const List<start_tournament_info_t>& robotfilename_list,
           char* lst[] = { "" };
 
           int row = gtk_clist_append( GTK_CLIST( tour_clist ), lst );
-#if GTK_MAJOR_VERSION != 1 || GTK_MINOR_VERSION < 1
           gtk_clist_set_foreground( GTK_CLIST( tour_clist ), row, 
                                     the_gui.get_fg_gdk_colour_p());
           gtk_clist_set_background( GTK_CLIST( tour_clist ), row, 
                                     the_gui.get_bg_gdk_colour_p());
-#endif
+
       
           String fname = info->filename;
           fname = get_segment( fname, fname.find( '/', 0, true ) + 1, -1 );
       
-#if GTK_MAJOR_VERSION == 1 && GTK_MINOR_VERSION >= 1
           gtk_clist_set_text( GTK_CLIST( tour_clist ),
                               row, 0, fname.chars() );
-#else
-          gtk_clist_set_text( GTK_CLIST( tour_clist ),
-                              row, 0, fname.non_const_chars() );
-#endif
           info->selected = false;
           info->row = row;
           tour_list->insert_last( new start_tournament_info_t
@@ -969,12 +955,11 @@ StartTournamentWindow::add_all_selected( const bool robots )
           char * list[] = { "" };
           
           int row = gtk_clist_append( GTK_CLIST( clist_tourn ), list );
-#if GTK_MAJOR_VERSION != 1 || GTK_MINOR_VERSION < 1
           gtk_clist_set_foreground( GTK_CLIST( clist_tourn ), row,
                                     the_gui.get_fg_gdk_colour_p() );
           gtk_clist_set_background( GTK_CLIST( clist_tourn ), row,
                                     the_gui.get_bg_gdk_colour_p() );
-#endif
+
 
           gtk_clist_set_text( GTK_CLIST( clist_tourn ), row, 0,
                               info_dir_p->filename.non_const_chars() );
