@@ -48,15 +48,11 @@ StatisticsWindow::StatisticsWindow( const int default_width,
   gtk_container_border_width( GTK_CONTAINER( window_p ), 12 );
 
   if( default_width != -1 && default_height != -1 )
-#if GTK_MAJOR_VERSION == 1 && GTK_MINOR_VERSION >= 1
     {
       gtk_window_set_default_size( GTK_WINDOW( window_p ),
                                    default_width, default_height );
       gtk_widget_set_usize( window_p , 364, 130 );
     }
-#else
-    gtk_widget_set_usize( window_p, default_width, default_height );
-#endif
   if( default_x_pos != -1 && default_y_pos != -1 )
     gtk_widget_set_uposition( window_p, default_x_pos, default_y_pos );
 
@@ -214,7 +210,6 @@ StatisticsWindow::StatisticsWindow( const int default_width,
       }
   }
 
-#if GTK_MAJOR_VERSION == 1 && GTK_MINOR_VERSION >= 1
   GtkObject* hadj = gtk_adjustment_new( 0.0, 0.0, 100.0, 1.0, 1.0, 1.0 );
   GtkObject* vadj = gtk_adjustment_new( 0.0, 0.0, 100.0, 1.0, 1.0, 1.0 );
   GtkWidget* scrolled_win = gtk_scrolled_window_new( GTK_ADJUSTMENT( hadj ),
@@ -223,7 +218,6 @@ StatisticsWindow::StatisticsWindow( const int default_width,
                                   GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC );
   gtk_box_pack_start( GTK_BOX( vbox ), scrolled_win, TRUE, TRUE, 0);
   gtk_widget_show( scrolled_win );
-#endif
 
   char * titles[7] = { "",_("Name"), _("Position"), _("Points"),
                        _("Games"), _("Survival Time"), _("Total Points") };
@@ -254,7 +248,6 @@ StatisticsWindow::StatisticsWindow( const int default_width,
   gtk_signal_connect( GTK_OBJECT( clist ), "select_row",
                       (GtkSignalFunc) row_selected, this );
 
-#if GTK_MAJOR_VERSION == 1 && GTK_MINOR_VERSION >= 1
   gtk_clist_set_column_resizeable( GTK_CLIST( clist ), 0, FALSE );
   gtk_clist_set_column_max_width( GTK_CLIST( clist ), 0, 5 );
 
@@ -281,12 +274,6 @@ StatisticsWindow::StatisticsWindow( const int default_width,
   clist_style->bg[GTK_STATE_SELECTED] = make_gdk_colour( 0xf0d2b4 );
   clist_style->fg[GTK_STATE_SELECTED] = *(the_gui.get_fg_gdk_colour_p());
   gtk_widget_set_style( clist, clist_style );
-#else
-  gtk_clist_set_border( GTK_CLIST( clist ), GTK_SHADOW_IN );
-  gtk_clist_set_policy( GTK_CLIST( clist ), GTK_POLICY_AUTOMATIC,
-                       GTK_POLICY_AUTOMATIC );
-  gtk_box_pack_start( GTK_BOX( vbox ), clist, TRUE, TRUE, 0 );
-#endif
   gtk_widget_show( clist );
 
   add_the_statistics_to_clist( clist, this );
@@ -365,31 +352,19 @@ StatisticsWindow::change_table_type( GtkWidget* widget,
     {
       if( info_p->type == STAT_TYPE_TOTAL || info_p->type == STAT_TYPE_SEQUENCE )
         {
-#if GTK_MAJOR_VERSION == 1 && GTK_MINOR_VERSION >= 1
           gtk_clist_set_column_visibility( GTK_CLIST( clist ),4, TRUE );
-#else
-          gtk_clist_set_column_title( GTK_CLIST( clist ), 4, _("Games") );
-          gtk_clist_set_column_width( GTK_CLIST( clist ), 4, 45 );
-#endif
         }
       else
         {
-#if GTK_MAJOR_VERSION == 1 && GTK_MINOR_VERSION >= 1
           gtk_clist_set_column_visibility ( GTK_CLIST( clist ),4,FALSE );
-#else
-          gtk_clist_set_column_title( GTK_CLIST( clist ), 4, "" );
-          gtk_clist_set_column_width( GTK_CLIST( clist ), 4, 0 );
-#endif
         }
       if(sw_type == STAT_TYPE_ROBOT && info_p->type != STAT_TYPE_ROBOT)
         {
-#if GTK_MAJOR_VERSION == 1 && GTK_MINOR_VERSION >= 1
           gtk_clist_set_column_resizeable( GTK_CLIST( clist ), 0, FALSE );
           gtk_clist_set_column_max_width( GTK_CLIST( clist ), 0, 5 );
 
           gtk_clist_set_column_auto_resize( GTK_CLIST( clist ), 0, FALSE );
           gtk_clist_set_column_auto_resize( GTK_CLIST( clist ), 1, FALSE );
-#endif
           gtk_clist_set_column_title( GTK_CLIST( clist ), 0, "" );
           gtk_clist_set_column_title( GTK_CLIST( clist ), 1, _("Name") );
           gtk_clist_column_title_passive( GTK_CLIST( clist ), 0 );
@@ -402,13 +377,11 @@ StatisticsWindow::change_table_type( GtkWidget* widget,
         }
       if(sw_type != STAT_TYPE_ROBOT && info_p->type == STAT_TYPE_ROBOT)
         {
-#if GTK_MAJOR_VERSION == 1 && GTK_MINOR_VERSION >= 1
           gtk_clist_set_column_resizeable( GTK_CLIST( clist ), 0, TRUE );
           gtk_clist_set_column_max_width( GTK_CLIST( clist ), 0, 10000 );
 
           gtk_clist_set_column_auto_resize( GTK_CLIST( clist ), 0, TRUE );
           gtk_clist_set_column_auto_resize( GTK_CLIST( clist ), 1, TRUE );
-#endif
           gtk_clist_set_column_title( GTK_CLIST( clist ), 0, _("Seq") );
           gtk_clist_set_column_title( GTK_CLIST( clist ), 1, _("Game") );
           gtk_clist_column_title_active( GTK_CLIST( clist ), 0 );
@@ -751,10 +724,7 @@ StatisticsWindow::add_the_statistics_to_clist( GtkWidget* widget,
       break;
     }
 
-#if GTK_MAJOR_VERSION == 1 && GTK_MINOR_VERSION >= 1
   gtk_clist_sort( GTK_CLIST( clist ) );
-  //  gtk_clist_columns_autosize( GTK_CLIST( clist ) );
-#endif
   gtk_clist_thaw( GTK_CLIST( clist ) );
 }
 
@@ -762,7 +732,6 @@ void
 StatisticsWindow::change_sorting_in_clist( GtkCList* clist, gint column,
                                            class StatisticsWindow* sw_p )
 {
-#if GTK_MAJOR_VERSION == 1 && GTK_MINOR_VERSION >= 1
   stat_types sw_type = sw_p->get_type();
   
   gtk_clist_freeze( clist );
@@ -819,7 +788,6 @@ StatisticsWindow::change_sorting_in_clist( GtkCList* clist, gint column,
     }
   add_the_statistics_to_clist( GTK_WIDGET( clist ), sw_p );
   gtk_clist_thaw( clist );
-#endif
 }
 
 void
