@@ -22,14 +22,18 @@ Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 #endif
 
 #include <string.h>
-#include <iostream.h>
-#include <strstream.h>
-#include <iomanip.h>
+#include <iostream>
+//#include <strstream>
+#include <iomanip>
 #include <stdlib.h>
 #include <ctype.h>
 
+using namespace std;
+
+#include "IntlDefs.h"
 #include "String.h"
 
+
 void Error(const bool fatal, const String& function_name, const String& error_msg);
 
 String::String()
@@ -109,15 +113,30 @@ String::String(const long int n)
 
 String::String(const double x, const int digits, const string_double_t form)
 {
-  buf_size = 0;
-  strstream ss;
-  if( form == STRING_NORMAL_FORM ) 
-    ss << setprecision(digits) << x << endl;
-  else
+  if( form == STRING_NORMAL_FORM ) {
+	// ss << setprecision(digits) << x << endl;
+	// Problems with internationalisation
+	// Fall back to good old shitty sprintf() 
+	  
+	buf_size = 0;
+ 	length = 15;
+    allocate_array(15);
+	  
+	sprintf(array , "%f", x);
+  } 
+  else {
+	/*buf_size = 0;
+  	strstream ss;  
     ss << (form == STRING_EXP_FORM ? setiosflags(ios::scientific) : setiosflags(ios::fixed)) 
        << setprecision(digits) << x << endl;
-
-  ss >> *this;
+    ss >> *this;*/
+	buf_size = 0;
+ 	length = 15;
+    allocate_array(15);
+	  
+	sprintf(array , "%e", x); 
+	  
+  }
 }
 
 String::~String()
